@@ -3,7 +3,7 @@
 #include <R.h>
 #include <Rinternals.h>
 
-SEXP find_windowC(SEXP Rpositions, SEXP Rstart, SEXP Rend, SEXP RMERKEN)
+extern SEXP find_windowC(SEXP Rpositions, SEXP Rstart, SEXP Rend, SEXP RMERKEN)
 {
 
 SEXP val        = R_NilValue;
@@ -11,10 +11,15 @@ PROTECT(val     = Rf_allocVector(INTSXP,2));
 INTEGER(val)[0] = 0;
 INTEGER(val)[1] = 0;
 
- Rstart       = coerceVector(Rstart, REALSXP);
- Rend         = coerceVector(Rend, REALSXP);
- Rpositions   = coerceVector(Rpositions, REALSXP);
- RMERKEN      = coerceVector(RMERKEN, INTSXP);
+Rstart       = coerceVector(Rstart, REALSXP);
+PROTECT(Rstart);
+Rend         = coerceVector(Rend, REALSXP);
+PROTECT(Rend);
+Rpositions   = coerceVector(Rpositions, REALSXP);
+PROTECT(Rpositions);
+RMERKEN      = coerceVector(RMERKEN, INTSXP);
+PROTECT(RMERKEN);  
+
 
 long int size;
 double *start  = REAL(Rstart);
@@ -27,11 +32,11 @@ size           = length(Rpositions);
 long int begin = merken[0] - 1;
 
 if(start[0]>pos[size-1]){
-    UNPROTECT(1);
+    UNPROTECT(5);
  return R_NilValue;
 }
 if(end[0]<pos[0]){
-   UNPROTECT(1);
+   UNPROTECT(5);
  return R_NilValue;
 }
 
@@ -42,7 +47,7 @@ for(long int i=begin; i < size; i++) {
    if(start[0]<=pos[i]){
 
        if(start[0]<pos[i] && end[0]<pos[i]){
-          UNPROTECT(1);
+          UNPROTECT(5);
           return R_NilValue;
        }
        INTEGER(val)[0]=i+1; // left side found
@@ -64,7 +69,7 @@ for(long int i=begin; i < size; i++) {
 }
 
 mark:
-UNPROTECT(1);
+UNPROTECT(5);
 return val;
 
 
